==> haskell-text-builder-0.6.6.1-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-builder
version:              0.6.6.1
visibility:           public
id:                   text-builder-0.6.6.1-IrLO2UVgnra3B48tU7UUfj
key:                  text-builder-0.6.6.1-IrLO2UVgnra3B48tU7UUfj
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder
synopsis:             An efficient strict text builder
category:             Text
abi:                  0d3df3af30667f57d651b1c816fb1c4c
exposed:              True
exposed-modules:      Text.Builder
hidden-modules:       Text.Builder.UTF16 Text.Builder.Prelude
import-dirs:          /usr/lib/ghc-8.10.1/site-local/text-builder-0.6.6.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/text-builder-0.6.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/text-builder-0.6.6.1
hs-libraries:         HStext-builder-0.6.6.1-IrLO2UVgnra3B48tU7UUfj
depends:
    base-4.14.0.0 bytestring-0.10.10.0
    deferred-folds-0.9.10.1-bkxh1O5nkABGH6dOce5av text-1.2.3.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-text-builder/html/text-builder.haddock

haddock-html:         /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-builder-0.6.6.1-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-builder
version:              0.6.6.1
visibility:           public
id:                   text-builder-0.6.6.1-JoISWzqMXsuJbHAxLdbYci
key:                  text-builder-0.6.6.1-JoISWzqMXsuJbHAxLdbYci
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder
synopsis:             An efficient strict text builder
category:             Text
abi:                  36be2958978e280fd41764b91805c824
exposed:              True
exposed-modules:      Text.Builder
hidden-modules:       Text.Builder.UTF16 Text.Builder.Prelude
import-dirs:          /usr/lib/ghc-8.10.1/site-local/text-builder-0.6.6.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/text-builder-0.6.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/text-builder-0.6.6.1
hs-libraries:         HStext-builder-0.6.6.1-JoISWzqMXsuJbHAxLdbYci
depends:
    base-4.14.0.0 bytestring-0.10.10.0
    deferred-folds-0.9.10.1-GbQOXJZjfwB81xrLeAnZsl text-1.2.3.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-text-builder/html/text-builder.haddock

haddock-html:         /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
